@@ -27,12 +27,13 @@ information obtained from provided file (easystack) with build specifications.
 
 :author: Denis Kristak (Inuits)
 :author: Pavel Grochal (Inuits)
+:author: Kenneth Hoste (HPC-UGent)
 """
-
 from easybuild.base import fancylogger
 from easybuild.tools.build_log import EasyBuildError
 from easybuild.tools.filetools import read_file
 from easybuild.tools.module_naming_scheme.utilities import det_full_ec_version
+from easybuild.tools.py2vs3 import string_type
 from easybuild.tools.utilities import only_if_module_is_available
 try:
     import yaml
@@ -41,6 +42,25 @@ except ImportError:
 _log = fancylogger.getLogger('easystack', fname=False)
 
 
+def check_value(value, context):
+    """
+    Check whether specified value obtained from a YAML file in specified context represents is valid.
+    The value must be a string (not a float or an int).
+    """
+    if not isinstance(value, string_type):
+        error_msg = '\n'.join([
+            "Value %(value)s (of type %(type)s) obtained for %(context)s is not valid!",
+            "Make sure to wrap the value in single quotes (like '%(value)s') to avoid that it is interpreted "
+            "by the YAML parser as a non-string value.",
+        ])
+        format_info = {
+            'context': context,
+            'type': type(value),
+            'value': value,
+        }
+        raise EasyBuildError(error_msg % format_info)
+
+
 class EasyStack(object):
     """One class instance per easystack. General options + list of all SoftwareSpecs instances"""
 
@@ -90,7 +110,12 @@ class EasyStackParser(object):
     def parse(filepath):
         """Parses YAML file and assigns obtained values to SW config instances as well as general config instance"""
         yaml_txt = read_file(filepath)
-        easystack_raw = yaml.safe_load(yaml_txt)
+
+        try:
+            easystack_raw = yaml.safe_load(yaml_txt)
+        except yaml.YAMLError as err:
+            raise EasyBuildError("Failed to parse %s: %s" % (filepath, err))
+
         easystack = EasyStack()
 
         try:
@@ -103,13 +128,13 @@ class EasyStackParser(object):
         for name in software:
             # ensure we have a string value (YAML parser returns type = dict
             # if levels under the current attribute are present)
-            name = str(name)
+            check_value(name, "software name")
             try:
                 toolchains = software[name]['toolchains']
             except KeyError:
                 raise EasyBuildError("Toolchains for software '%s' are not defined in %s", name, filepath)
             for toolchain in toolchains:
-                toolchain = str(toolchain)
+                check_value(toolchain, "software %s" % name)
 
                 if toolchain == 'SYSTEM':
                     toolchain_name, toolchain_version = 'system', ''
@@ -140,12 +165,13 @@ class EasyStackParser(object):
                 # Example of yaml structure:
                 # ========================================================================
                 # versions:
-                #   2.25:
-                #   2.23:
+                #   '2.25':
+                #   '2.23':
                 #     versionsuffix: '-R-4.0.0'
                 # ========================================================================
                 if isinstance(versions, dict):
                     for version in versions:
+                        check_value(version, "%s (with %s toolchain)" % (name, toolchain_name))
                         if versions[version] is not None:
                             version_spec = versions[version]
                             if 'versionsuffix' in version_spec:
@@ -172,35 +198,25 @@ class EasyStackParser(object):
                         easystack.software_list.append(sw)
                     continue
 
-                # is format read as a list of versions?
-                # ========================================================================
-                # versions:
-                #   [2.24, 2.51]
-                # ========================================================================
-                elif isinstance(versions, list):
-                    versions_list = versions
+                elif isinstance(versions, (list, tuple)):
+                    pass
 
-                # format = multiple lines without ':' (read as a string)?
-                # ========================================================================
+                # multiple lines without ':' is read as a single string; example:
                 # versions:
-                #   2.24
-                #   2.51
-                # ========================================================================
-                elif isinstance(versions, str):
-                    versions_list = str(versions).split()
+                #   '2.24'
+                #   '2.51'
+                elif isinstance(versions, string_type):
+                    versions = versions.split()
 
-                # format read as float (containing one version only)?
-                # ========================================================================
-                # versions:
-                #   2.24
-                # ========================================================================
-                elif isinstance(versions, float):
-                    versions_list = [str(versions)]
+                # single values like '2.24' should be wrapped in a list
+                else:
+                    versions = [versions]
 
-                # if no version is a dictionary, versionsuffix isn't specified
+                # if version is not a dictionary, versionsuffix is not specified
                 versionsuffix = ''
 
-                for version in versions_list:
+                for version in versions:
+                    check_value(version, "%s (with %s toolchain)" % (name, toolchain_name))
                     sw = SoftwareSpecs(
                         name=name, version=version, versionsuffix=versionsuffix,
                         toolchain_name=toolchain_name, toolchain_version=toolchain_version)
