@@ -27,6 +27,8 @@ EasyBuild support for a GCC+CUDA compiler toolchain.
 
 :author: Kenneth Hoste (Ghent University)
 """
+import re
+from distutils.version import LooseVersion
 
 from easybuild.toolchains.compiler.cuda import Cuda
 from easybuild.toolchains.gcc import GccToolchain
@@ -38,3 +40,20 @@ class GccCUDA(GccToolchain, Cuda):
 
     COMPILER_MODULE_NAME = ['GCC', 'CUDA']
     SUBTOOLCHAIN = GccToolchain.NAME
+
+    def is_deprecated(self):
+        """Return whether or not this toolchain is deprecated."""
+        # need to transform a version like '2018b' with something that is safe to compare with '2019'
+        # comparing subversions that include letters causes TypeErrors in Python 3
+        # 'a' is assumed to be equivalent with '.01' (January), and 'b' with '.07' (June) (good enough for this purpose)
+        version = self.version.replace('a', '.01').replace('b', '.07')
+
+        deprecated = False
+
+        # make sure a non-symbolic version (e.g., 'system') is used before making comparisons using LooseVersion
+        if re.match('^[0-9]', version):
+            # gcccuda toolchains older than gcccuda/2019a are deprecated since EasyBuild v4.5.0
+            if LooseVersion(version) < LooseVersion('2019'):
+                deprecated = True
+
+        return deprecated
