@@ -29,6 +29,8 @@ Intel Math Kernel Library (MKL), and Intel FFTW wrappers.
 :author: Stijn De Weirdt (Ghent University)
 :author: Kenneth Hoste (Ghent University)
 """
+from distutils.version import LooseVersion
+import re
 
 from easybuild.toolchains.iompi import Iompi
 from easybuild.toolchains.iimkl import Iimkl
@@ -43,3 +45,19 @@ class Iomkl(Iompi, IntelMKL, IntelFFTW):
     """
     NAME = 'iomkl'
     SUBTOOLCHAIN = [Iompi.NAME, Iimkl.NAME]
+
+    def is_deprecated(self):
+        """Return whether or not this toolchain is deprecated."""
+        # need to transform a version like '2018b' with something that is safe to compare with '2019'
+        # comparing subversions that include letters causes TypeErrors in Python 3
+        # 'a' is assumed to be equivalent with '.01' (January), and 'b' with '.07' (June) (good enough for this purpose)
+        version = self.version.replace('a', '.01').replace('b', '.07')
+
+        # iomkl toolchains older than iomkl/2019a are deprecated since EasyBuild v4.5.0
+        # make sure a non-symbolic version (e.g., 'system') is used before making comparisons using LooseVersion
+        if re.match('^[0-9]', version) and LooseVersion(version) < LooseVersion('2019'):
+            deprecated = True
+        else:
+            deprecated = False
+
+        return deprecated
