@@ -48,6 +48,12 @@ from easybuild.base.frozendict import FrozenDictKnownKeys
 from easybuild.tools.build_log import EasyBuildError
 from easybuild.tools.py2vs3 import ascii_letters, create_base_metaclass, string_type
 
+try:
+    import rich  # noqa
+    HAVE_RICH = True
+except ImportError:
+    HAVE_RICH = False
+
 
 _log = fancylogger.getLogger('config', fname=False)
 
@@ -137,6 +143,13 @@ LOCAL_VAR_NAMING_CHECK_WARN = WARN
 LOCAL_VAR_NAMING_CHECKS = [LOCAL_VAR_NAMING_CHECK_ERROR, LOCAL_VAR_NAMING_CHECK_LOG, LOCAL_VAR_NAMING_CHECK_WARN]
 
 
+OUTPUT_STYLE_AUTO = 'auto'
+OUTPUT_STYLE_BASIC = 'basic'
+OUTPUT_STYLE_NO_COLOR = 'no_color'
+OUTPUT_STYLE_RICH = 'rich'
+OUTPUT_STYLES = (OUTPUT_STYLE_AUTO, OUTPUT_STYLE_BASIC, OUTPUT_STYLE_NO_COLOR, OUTPUT_STYLE_RICH)
+
+
 class Singleton(ABCMeta):
     """Serves as metaclass for classes that should implement the Singleton pattern.
 
@@ -186,6 +199,7 @@ BUILD_OPTIONS_CMDLINE = {
         'hide_toolchains',
         'http_header_fields_urlpat',
         'force_download',
+        'insecure_download',
         'from_pr',
         'git_working_dirs_path',
         'github_user',
@@ -256,6 +270,7 @@ BUILD_OPTIONS_CMDLINE = {
         'module_extensions',
         'module_only',
         'package',
+        'parallel_extensions_install',
         'read_only_installdir',
         'remove_ghost_install_dirs',
         'rebuild',
@@ -271,6 +286,7 @@ BUILD_OPTIONS_CMDLINE = {
         'generate_devel_module',
         'sticky_bit',
         'trace',
+        'unit_testing_mode',
         'upload_test_report',
         'update_modules_tool_cache',
         'use_ccache',
@@ -292,6 +308,7 @@ BUILD_OPTIONS_CMDLINE = {
         'map_toolchains',
         'modules_tool_version_check',
         'pre_create_installdir',
+        'show_progress_bar',
     ],
     WARN: [
         'check_ebroot_env_vars',
@@ -341,6 +358,9 @@ BUILD_OPTIONS_CMDLINE = {
     DEFAULT_WAIT_ON_LOCK_INTERVAL: [
         'wait_on_lock_interval',
     ],
+    OUTPUT_STYLE_AUTO: [
+        'output_style',
+    ],
 }
 # build option that do not have a perfectly matching command line option
 BUILD_OPTIONS_OTHER = {
@@ -687,6 +707,22 @@ def get_module_syntax():
     return ConfigurationVariables()['module_syntax']
 
 
+def get_output_style():
+    """Return output style to use."""
+    output_style = build_option('output_style')
+
+    if output_style == OUTPUT_STYLE_AUTO:
+        if HAVE_RICH:
+            output_style = OUTPUT_STYLE_RICH
+        else:
+            output_style = OUTPUT_STYLE_BASIC
+
+    if output_style == OUTPUT_STYLE_RICH and not HAVE_RICH:
+        raise EasyBuildError("Can't use '%s' output style, Rich Python package is not available!", OUTPUT_STYLE_RICH)
+
+    return output_style
+
+
 def log_file_format(return_directory=False, ec=None, date=None, timestamp=None):
     """
     Return the format for the logfile or the directory
