@@ -30,6 +30,7 @@ Toolchain specific variables
 """
 
 from easybuild.tools.build_log import EasyBuildError
+from easybuild.tools.systemtools import get_shared_lib_ext
 from easybuild.tools.variables import StrList, AbsPathList
 
 
@@ -111,8 +112,16 @@ class LibraryList(StrList):
                 self.END.PREFIX = prefix_begin_end
 
 
+class CommaSharedLibs(LibraryList):
+    """Comma-separated list of shared libraries"""
+    SEPARATOR = ','
+
+    PREFIX = 'lib'
+    SUFFIX = '.' + get_shared_lib_ext()
+
+
 class CommaStaticLibs(LibraryList):
-    """Comma-separated list"""
+    """Comma-separated list of static libraries"""
     SEPARATOR = ','
 
     PREFIX = 'lib'
